

import java.sql.*;
import javax.sql.*;
import java.util.*;
import javax.ejb.*;
import javax.naming.*;

public class WebAddressAccountBean implements EntityBean {

    
    private String urlName;
    private String urlDescript;
    
    private EntityContext context;
    private Connection con;
    
    private String dbName = "java:comp/env/jdbc/WebAddressAccountDB";

    
 
    public String getUrlName() {
     
       return urlName;
    }
 
    public String getUrlDescript() {
         
       return urlDescript;
    }

    public String ejbCreate( String urlName, 
       String urlDescript)
       throws CreateException 
       {
       	
       try {
          insertRow( urlName, urlDescript);
       } catch (Exception ex) {
       	   
           throw new EJBException("ejbCreate: " + 
              ex.getMessage());
       }
       try{
       this.urlName = urlName;
       this.urlDescript = urlDescript;
       
       }
       catch(Exception e)
       {System.out.println("in side ejb create :"+e.toString());}
       return urlName;
      }

   public String ejbFindByPrimaryKey(String primaryKey) 
      throws FinderException {
       
      boolean result;

      try {
         result = selectByPrimaryKey(primaryKey);
       } catch (Exception ex) {
           throw new EJBException("ejbFindByPrimaryKey: " + 
              ex.getMessage());
       }
      if (result) {
         return primaryKey;
      }
      else {
         throw new ObjectNotFoundException
            ("Row for urlName " + primaryKey + " not found.");
      }
   }

   public void ejbRemove() {
        
      try {
         deleteRow(urlName);
       } catch (Exception ex) {
           throw new EJBException("ejbRemove: " + 
              ex.getMessage());
       }
   } 

   public void setEntityContext(EntityContext context) {
         
      this.context = context;
      try {
         makeConnection();
      } catch (Exception ex) {
          throw new EJBException("Unable to connect to database. " +
             ex.getMessage());
      }
   }

   public void unsetEntityContext() {
        
      try {
         con.close();
      } catch (SQLException ex) {
          throw new EJBException("unsetEntityContext: " + ex.getMessage());
      }
   }

   public void ejbActivate() {
      urlName = (String)context.getPrimaryKey();
   }

   public void ejbPassivate() {
      urlName = null;
   }

   public void ejbLoad() {
      try {
         loadRow();
       } catch (Exception ex) {
           throw new EJBException("ejbLoad: " + 
              ex.getMessage());
       }
   }
   
   public void ejbStore() {
      try {
         storeRow();
       } catch (Exception ex) {
           throw new EJBException("ejbStore: " + 
              ex.getMessage());
       }
   }


   public void ejbPostCreate( String urlName, 
      String urlDescript) {  }


/*********************** Database Routines *************************/

   private void makeConnection() throws NamingException, SQLException {
        
      InitialContext ic = new InitialContext();
      DataSource ds = (DataSource) ic.lookup(dbName);
      con =  ds.getConnection();
   }

   private void insertRow ( String urlName, String urlDescript) 
   throws SQLException {
          String insertStatement =
                "insert into webAddressaccount values (  ? , ? )";
          try{      
          PreparedStatement prepStmt = 
                con.prepareStatement(insertStatement);

          
          prepStmt.setString(1, urlName);
          prepStmt.setString(2, urlDescript);
          
          prepStmt.executeUpdate();
          prepStmt.close();
        }
        catch(Exception e )
        { System.out.println("exception inside of insert Row ");
        }
   }

   private void deleteRow(String urlName) throws SQLException {
      String deleteStatement =
            "delete from webAddressaccount where urlName = ? ";
      PreparedStatement prepStmt =
            con.prepareStatement(deleteStatement);

      prepStmt.setString(1, urlName);
      prepStmt.executeUpdate();
      prepStmt.close();
   }

   private boolean selectByPrimaryKey(String primaryKey) 
      throws SQLException {
      
      String selectStatement =
            "select urlName " +
            "from webAddressaccount where urlName = ? ";
      PreparedStatement prepStmt =
            con.prepareStatement(selectStatement);
      prepStmt.setString(1, primaryKey);
         
      ResultSet rs = prepStmt.executeQuery();
      
      boolean result = rs.next();
      prepStmt.close();
      
      return result;
   }

   

   

   private void loadRow() throws SQLException {
      String selectStatement =
            "select urlDescript " +
            "from webAddressaccount where urlName = ? ";
      PreparedStatement prepStmt = 
            con.prepareStatement(selectStatement);

      prepStmt.setString(1, this.urlName);

      ResultSet rs = prepStmt.executeQuery();

      if (rs.next()) {
         
         this.urlDescript = rs.getString(1);
         
         prepStmt.close();
      }
      else {
         prepStmt.close();
         throw new NoSuchEntityException("Row for urlName " +urlName +
            " not found in database.");
      }
   }


   private void storeRow() throws SQLException {
      String updateStatement =
            "update webAddressaccount set " +
            "urlDescript = ?  " +
            "where urlName = ?";
      PreparedStatement prepStmt = 
            con.prepareStatement(updateStatement);

      prepStmt.setString(1, urlDescript);
      prepStmt.setString(2, urlName);
      
      int rowCount = prepStmt.executeUpdate();
      prepStmt.close();

      if (rowCount == 0) {
         throw new EJBException("Storing row for urlName " + urlName + " failed.");
      }
   }

} // WebAddressAccountBean 
